quantizationtools.SerialJobHandler
==================================

.. abjad-lineage:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler

.. autoclass:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler.SerialJobHandler.__repr__
   :noindex:
